package
Version:
v0.1.2
Opens a new window with list of versions in this module.
Published: Aug 7, 2026
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Options struct {
MaxFiles int
MaxBytes int64
}
type Result struct {
SourcePath string `json:"source_path"`
OutputDir string `json:"output_dir"`
ContentRoot string `json:"content_root"`
Files int `json:"files"`
Bytes int64 `json:"bytes"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.